@@ -5,7 +5,7 @@ package Test::Mojibake;
 use strict;
 use warnings qw(all);
 
-our $VERSION = '1.0'; # VERSION
+our $VERSION = '1.1'; # VERSION
 
 use File::Spec::Functions;
 use Test::Builder;
@@ -161,6 +161,11 @@ sub all_files_encoding_ok {
     ## no critic (ProhibitFiletest_f)
     my @files = map { -d $_ ? all_files($_) : (-f $_ ? $_ : ()) } @args;
 
+    unless (@files) {
+        $Test->plan(skip_all => 'could not find any files to test');
+        return;
+    }
+
     $Test->plan(tests => scalar @files);
 
     my $ok = 1;
@@ -306,7 +311,7 @@ Test::Mojibake - check your source for encoding misbehavior.
 
 =head1 VERSION
 
-version 1.0
+version 1.1
 
 =head1 SYNOPSIS
 
@@ -530,13 +535,25 @@ Stanislaw Pusep <stas@sysd.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Stanislaw Pusep.
+This software is copyright (c) 2015 by Stanislaw Pusep.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
+
+=for stopwords Dave Rolsky Karen Etheridge
+
+=over 4
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
 
 Karen Etheridge <ether@cpan.org>
 
+=back
+
 =cut
